@@ -58,11 +58,11 @@ def write_n_dics(n_dics):
 
     with open(path.join(fpath, "data", "dict_add.txt"), "w", encoding="utf8", errors="ignore") as da:
         for word in sorted(list(n_dics[3].keys())):
-            da.write(word)
+            da.write(word + "\n")
 
     with open(path.join(fpath, "data", "dict_don't_add.txt"), "w", encoding="utf8", errors="ignore") as blf:
         for word in sorted(list(n_dics[3].keys())):
-            blf.write(word)
+            blf.write(word + "\n")
 
 
 def dict_to_md5(c_dics):
@@ -103,7 +103,8 @@ def check_to_server(c_dics_md5):
     js = json.dumps(jd, ensure_ascii=False, indent=4)
     r = requests.post(server_ip, data={'data': js})
     re = r.text
-    if_news = json.loads(re)["if_news"]
+    rj = json.loads(re)
+    if_news = ["if_news"]
     return if_news
 
 
